@@ -786,7 +786,7 @@ class Page(Plugin):
             self.db.set(RECOVERY_TYPE_QUESTION, rec_type)
 
         #If we were preseeded to dynamic, look for an RP
-        rec_part = magic.find_factory_rp_stats()
+        rec_part = magic.find_factory_partition_stats('rp')
         if "slave" in rec_part:
             self.stage = 2
         if rec_type == 'dynamic':
